@@ -4,9 +4,6 @@ from pydantic import BaseModel
 
 
 class ActionStatus(str, Enum):
-    """
-    Action status.
-    """
     success = "success"
     failure = "failure"
 
@@ -16,7 +13,19 @@ T = TypeVar("T")
 
 class Result(BaseModel, Generic[T]):
     """
-
+    Factory result class.
+    Has status, data, error fields.
+    Used for general definition of function`s restult.
+    Example:
+    def send_data_to_remote(data, url):
+    	response = post(url, data=data)
+    	try:
+	    if response.status == 200:
+	        return Result.success(data=response.json)
+	    else:
+	        return Result.failure(error=response.text)
+	except Exception as error:
+	    return Result.server_error(error=str(error))
     """
     status: ActionStatus
     data: Optional[T]
