@@ -1,8 +1,4 @@
-import http
-from typing import Any, Dict, Optional, Sequence, Type
-
-from pydantic import BaseModel, ValidationError, create_model
-from pydantic.error_wrappers import ErrorList
+from typing import Any, Dict, Optional
 
 
 class BaseHTTPException(Exception):
@@ -12,8 +8,6 @@ class BaseHTTPException(Exception):
         detail: Optional[str] = None,
         headers: Optional[dict] = None,
     ) -> None:
-        if detail is None:
-            detail = http.HTTPStatus(status_code).phrase
         self.status_code = status_code
         self.detail = detail
         self.headers = headers
@@ -23,7 +17,7 @@ class BaseHTTPException(Exception):
         return f"{class_name}(status_code={self.status_code!r}, detail={self.detail!r})"
 
 
-class WebSocketException(Exception):
+class BaseWebSocketException(Exception):
     def __init__(self, code: int, reason: Optional[str] = None) -> None:
         self.code = code
         self.reason = reason or ""
@@ -33,7 +27,6 @@ class WebSocketException(Exception):
         return f"{cls_name}(code={self.code!r}, reason={self.reason!r})"
 
 
-
 class HTTPException(BaseHTTPException):
     def __init__(
         self,
@@ -44,17 +37,6 @@ class HTTPException(BaseHTTPException):
         super().__init__(status_code=status_code, detail=detail, headers=headers)
 
 
-RequestErrorModel: Type[BaseModel] = create_model("Request")
-WebSocketErrorModel: Type[BaseModel] = create_model("WebSocket")
-
-
-class RequestValidationError(ValidationError):
-    def __init__(self, errors: Sequence[ErrorList], *, body: Any = None) -> None:
-        self.body = body
-        super().__init__(errors, RequestErrorModel)
-
-
-class WebSocketRequestValidationError(ValidationError):
-    def __init__(self, errors: Sequence[ErrorList]) -> None:
-        super().__init__(errors, WebSocketErrorModel)
-
+class WSException(BaseWebSocketException):
+    def __init__(self, code: int, reason: Optional[str] = None) -> None:
+        super().__init__(code=code, reason=reason)
