@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import TypeVar, Generic, Optional
+from typing import TypeVar, Generic, Optional, Union
 from pydantic import BaseModel
 
 from .exc.http_exc import HTTPException
@@ -33,7 +33,7 @@ class HttpResult(BaseModel, Generic[T]):
     """
     status: ActionStatus
     data: Optional[T]
-    exc: Exception
+    exc: Union[Exception, Optional[T]]
     detail: Optional[str]
 
     class Config:
@@ -50,7 +50,7 @@ class HttpResult(BaseModel, Generic[T]):
         return HttpResult(status=ActionStatus.success, data=data, detail=detail)
 
     @classmethod
-    def failure(cls, exc: Exception):
+    def failure(cls, exc: Union[Exception, Optional[T]]):
         return HttpResult(status=ActionStatus.failure, exc=exc)
 
     @classmethod
